@@ -3,7 +3,9 @@ import os
 import binascii
 import codecs
 import grpc
+import json
 from google.protobuf.json_format import MessageToJson
+from google.protobuf.json_format import MessageToDict
 from python_lnd_grpc.lnd_defaults import defaultTLSCertFilename, defaultAdminMacFilename, defaultNetwork, defaultRPCHost, defaultRPCPort
 import python_lnd_grpc.protos.rpc_pb2 as lnrpc
 import python_lnd_grpc.protos.rpc_pb2_grpc as rpcstub
@@ -28,7 +30,8 @@ class Connector(object):
         grpc_port: str = defaultRPCPort,
         custom_tls_path_full: str = None,
         custom_macaroon_path_full: str = None,
-        output: str = None):
+        output: str = None,
+        macaroon_bytes: bytes = None):
 
         # TODO move to separate method
         if custom_tls_path_full is not None:
@@ -42,12 +45,18 @@ class Connector(object):
             self.full_macaroon_path = os.path.expanduser(custom_macaroon_path_full)
         else:
             self.full_macaroon_path = os.path.expanduser((macaroon_path + '{}/' + macaroon_filename).format(network))
+        
         # print(self.full_macaroon_path)
         with open(self.tls_file, 'rb') as f:
             self.cert = f.read()
-        with open(self.full_macaroon_path, 'rb') as f:
-            self.macaroon_bytes = f.read()
-            self.macaroon = codecs.encode(self.macaroon_bytes, 'hex')
+
+        if macaroon_bytes is not None:
+            self.macaroon = codecs.encode(macaroon_bytes, 'hex')
+        else:    
+            with open(self.full_macaroon_path, 'rb') as f:
+                self.macaroon_bytes = f.read()
+                self.macaroon = codecs.encode(self.macaroon_bytes, 'hex')
+
         self.headers = {'Grpc-Metadata-macaroon': self.macaroon}
         self.host = grpc_host
         self.port = grpc_port
@@ -78,9 +87,13 @@ class Connector(object):
 
     def out(self, response):
         if self.output == "json":
-            return MessageToJson(response)
+            return json.dumps(MessageToDict(response))
         elif self.output == "json-none-included":
-            return MessageToJson(response, including_default_value_fields=True)
+            return json.dumps(MessageToDict(response, including_default_value_fields=True))
+        elif self.output == "dictionary":
+            return MessageToDict(response)
+        elif self.output == "dictionary-none-included":
+            return MessageToDict(response, including_default_value_fields=True)
         else:
             return response
 
@@ -143,7 +156,7 @@ class LNDMethods(Connector):
         return self.out(response)
 
     # https://api.lightning.community/#closechannel
-    def closechannel(self, channel_point, force: bool, target_conf: int, sat_per_byte: int, delivery_address: str):
+    def closechannel(self, channel_point, force: bool = None, target_conf: int = None, sat_per_byte: int = None, delivery_address: str = None):
         request = lnrpc.CloseChannelRequest(
             channel_point=channel_point,
             force=force,
